@@ -24,132 +24,135 @@
 
 
 // The file separator
-#ifdef _WIN32
-string fs("\\");
-#else
-string fs("/");
-#endif
+std::string fs(PATHSEP);
 
 
 // test static functions
 int test1() {
   // create test file using C++ functions
-  ofstream input1;
-  input1.open("input1.txt", ofstream::out | ofstream::binary);
+  std::ofstream input1;
+  input1.open("input1.txt", std::ofstream::out | std::ofstream::binary);
   const char *input1_contents = "diskfile_test test1 input1.txt";
   input1 << input1_contents;
   input1.close();
 
-  ofstream input2;
-  input2.open("input2.txt", ofstream::out | ofstream::binary);
+  std::ofstream input2;
+  input2.open("input2.txt", std::ofstream::out | std::ofstream::binary);
   const char *input2_contents = "diskfile_test test1 input2.txt";
   input2 << input2_contents;
   input2.close();
 
   if (DiskFile::FileExists("definitely_not_here")) {
-    cout << "said file exists when it doesn't" << endl;
+    std::cout << "said file exists when it doesn't" << std::endl;
     return 1;
   }
   if (!DiskFile::FileExists("input1.txt")) {
-    cout << "said file doesn't exists when it does" << endl;
+    std::cout << "said file doesn't exists when it does" << std::endl;
     return 1;
   }
 
   if (DiskFile::GetFileSize("input1.txt") != strlen(input1_contents)) {
-    cout << "GetFileSize returned wrong value" << endl;
+    std::cout << "GetFileSize returned wrong value" << std::endl;
     return 1;
   }
 
-  std::unique_ptr< list<string> > files = DiskFile::FindFiles(".", "input1.txt", false);
+  std::unique_ptr< std::list<std::string> > files = DiskFile::FindFiles(".", "input1.txt", false);
   if (files->size() != 1 || *(files->begin()) != "." + fs + "input1.txt") {
-    cout << "FindFiles failed on exact name" << endl;
-    cout << "   size=" << files->size() << endl;
-    for (list<string>::iterator fn = files->begin();
+    std::cout << "FindFiles failed on exact name" << std::endl;
+    std::cout << "   size=" << files->size() << std::endl;
+    for (std::list<std::string>::iterator fn = files->begin();
 	 fn != files->end();
 	 fn++) {
-      cout << "   " << *fn << endl;
+      std::cout << "   " << *fn << std::endl;
     }
 
     return 1;
   }
   files = DiskFile::FindFiles(".", "input?.txt", false);
   if (files->size() != 2
-      || find(files->begin(), files->end(), string("." + fs + "input1.txt")) == files->end()
-      || find(files->begin(), files->end(), string("." + fs + "input2.txt")) == files->end()) {
-    cout << "FindFiles failed on ?" << endl;
+      || find(files->begin(), files->end(), std::string("." + fs + "input1.txt")) == files->end()
+      || find(files->begin(), files->end(), std::string("." + fs + "input2.txt")) == files->end()) {
+    std::cout << "FindFiles failed on ?" << std::endl;
     return 1;
   }
   files = DiskFile::FindFiles(".", "input1?.txt", false);
-  if (!files->empty()) {
-    cout << "FindFiles failed on empty ?" << endl;
+#ifdef _WIN32
+  if (files->size() != 1 || *(files->begin()) != "." + fs + "input1.txt") {
+    std::cout << "FindFiles failed on empty ?" << std::endl;
     return 1;
   }
+#else
+  if (!files->empty()) {
+    std::cout << "FindFiles failed on empty ?" << std::endl;
+    return 1;
+  }
+#endif
   files = DiskFile::FindFiles(".", "input*.txt", false);
   if (files->size() != 2
-      || find(files->begin(), files->end(), string("." + fs + "input1.txt")) == files->end()
-      || find(files->begin(), files->end(), string("." + fs + "input2.txt")) == files->end()) {
-    cout << "FindFiles failed on *" << endl;
+      || find(files->begin(), files->end(), std::string("." + fs + "input1.txt")) == files->end()
+      || find(files->begin(), files->end(), std::string("." + fs + "input2.txt")) == files->end()) {
+    std::cout << "FindFiles failed on *" << std::endl;
     return 1;
   }
   files = DiskFile::FindFiles(".", "input1*.txt", false);
   if (files->size() != 1 || *(files->begin()) != "." + fs + "input1.txt") {
-    cout << "FindFiles failed on empty *" << endl;
+    std::cout << "FindFiles failed on empty *" << std::endl;
 //TODO: Fix bug and uncomment this
 //    return 1;
   }
   files = DiskFile::FindFiles(".", "i*p*t*.txt", false);
   if (files->size() != 2
-      || find(files->begin(), files->end(), string("." + fs + "input1.txt")) == files->end()
-      || find(files->begin(), files->end(), string("." + fs + "input2.txt")) == files->end()) {
-    cout << "FindFiles failed on multiple *" << endl;
+      || find(files->begin(), files->end(), std::string("." + fs + "input1.txt")) == files->end()
+      || find(files->begin(), files->end(), std::string("." + fs + "input2.txt")) == files->end()) {
+    std::cout << "FindFiles failed on multiple *" << std::endl;
 //TODO: Fix bug and uncomment this
 //    return 1;
   }
 
 
   { // scope to hide variable names
-    string path, name;
+    std::string path, name;
     DiskFile::SplitFilename("input1.txt", path, name);
     if (path != "." + fs
 	|| name != "input1.txt") {
-      cout << "CanonicalPathname + SplitFilename failed on input1.txt" << endl;
+      std::cout << "CanonicalPathname + SplitFilename failed on input1.txt" << std::endl;
       return 1;
     }
     // NB: Keeping value of path, name to see if overwritten
     DiskFile::SplitFilename("." + fs + "input1.txt", path, name);
     if (path != "." + fs
 	|| name != "input1.txt") {
-      cout << "CanonicalPathname + SplitFilename failed on input1.txt" << endl;
+      std::cout << "CanonicalPathname + SplitFilename failed on input1.txt" << std::endl;
       return 1;
     }
     DiskFile::SplitFilename("dir" + fs + "input1.txt", path, name);
     if (path != "dir" + fs
 	|| name != "input1.txt") {
-      cout << "CanonicalPathname + SplitFilename failed on input1.txt" << endl;
+      std::cout << "CanonicalPathname + SplitFilename failed on input1.txt" << std::endl;
       return 1;
     }
     DiskFile::SplitFilename("multiple" + fs + "dirs" + fs + "input1.txt", path, name);
     if (path != "multiple" + fs + "dirs" + fs
 	|| name != "input1.txt") {
-      cout << "CanonicalPathname + SplitFilename failed on input1.txt" << endl;
+      std::cout << "CanonicalPathname + SplitFilename failed on input1.txt" << std::endl;
       return 1;
     }
     DiskFile::SplitFilename(fs + "root_dir" + fs + "input1.txt", path, name);
     if (path != fs + "root_dir" + fs
 	|| name != "input1.txt") {
-      cout << "CanonicalPathname + SplitFilename failed on input1.txt" << endl;
+      std::cout << "CanonicalPathname + SplitFilename failed on input1.txt" << std::endl;
       return 1;
     }
   }
 
 
   {
-    string name;
+    std::string name;
     DiskFile::SplitRelativeFilename("root" + fs + "dir" + fs + "input1.txt",
 			    "root" + fs + "dir" + fs,
 			    name);
     if (name != "input1.txt") {
-      cout << "SplitRelativeFilename failed for full path" << endl;
+      std::cout << "SplitRelativeFilename failed for full path" << std::endl;
       return 1;
     }
     // intentionally reusing name to see if it is overwritten
@@ -157,15 +160,15 @@ int test1() {
 			    "root" + fs,
 			    name);
     if (name != "dir" + fs + "input1.txt") {
-      cout << "SplitRelativeFilename failed for partial path" << endl;
+      std::cout << "SplitRelativeFilename failed for partial path" << std::endl;
       return 1;
     }
   }
 
 
   { // scope to hide variable names
-    string path_and_name1 = DiskFile::GetCanonicalPathname("input1.txt");
-    string path1, name1;
+    std::string path_and_name1 = DiskFile::GetCanonicalPathname("input1.txt");
+    std::string path1, name1;
     DiskFile::SplitFilename(path_and_name1, path1, name1);
     if (path_and_name1 != path1 + name1
 #ifdef _WIN32
@@ -174,23 +177,23 @@ int test1() {
 	|| path1.at(0) != fs.at(0)
 #endif
 	|| name1 != "input1.txt") {
-      cout << "CanonicalPathname + SplitFilename failed on input1.txt" << endl;
+      std::cout << "CanonicalPathname + SplitFilename failed on input1.txt" << std::endl;
       return 1;
     }
-    string path_and_name2 = DiskFile::GetCanonicalPathname("input2.txt");
-    string path2, name2;
+    std::string path_and_name2 = DiskFile::GetCanonicalPathname("input2.txt");
+    std::string path2, name2;
     DiskFile::SplitFilename(path_and_name2, path2, name2);
     if (path_and_name2 != path2 + name2
 	|| path2 != path1
 	|| name2 != "input2.txt") {
-      cout << "CanonicalPathname + SplitFilename failed on input2.txt" << endl;
+      std::cout << "CanonicalPathname + SplitFilename failed on input2.txt" << std::endl;
       return 1;
     }
 
     // check that ././input1.txt is the same as input1.txt
-    string path_and_name3 = DiskFile::GetCanonicalPathname("." + fs + "." + fs + "input1.txt");
+    std::string path_and_name3 = DiskFile::GetCanonicalPathname("." + fs + "." + fs + "input1.txt");
     if (path_and_name3 != path_and_name1) {
-      cout << "CanonicalPathname + SplitFilename failed on ././input.txt" << endl;
+      std::cout << "CanonicalPathname + SplitFilename failed on ././input.txt" << std::endl;
       return 1;
     }
   }
@@ -207,56 +210,56 @@ int test1() {
 // test non-static functions
 int test2() {
   // create test file using C++ functions
-  ofstream input1;
-  input1.open("input1.txt", ofstream::out | ofstream::binary);
+  std::ofstream input1;
+  input1.open("input1.txt", std::ofstream::out | std::ofstream::binary);
   const char *input1_contents = "diskfile_test test1 input1.txt";
   input1 << input1_contents;
   input1.close();
 
   // read input1.txt
   {
-    DiskFile diskfile(cout, cerr);
+    DiskFile diskfile(std::cout, std::cerr);
     if (diskfile.IsOpen()) {
-      cout << "IsOpen failed 1" << endl;
+      std::cout << "IsOpen failed 1" << std::endl;
       return 1;
     }
     if (diskfile.Exists()) {
-      cout << "Exists failed 1" << endl;
+      std::cout << "Exists failed 1" << std::endl;
       return 1;
     }
     if (!diskfile.Open("input1.txt")) {
-      cout << "Open failed" << endl;
+      std::cout << "Open failed" << std::endl;
       return 1;
     }
     if (!diskfile.IsOpen()) {
-      cout << "IsOpen failed 2" << endl;
+      std::cout << "IsOpen failed 2" << std::endl;
       return 1;
     }
     if (!diskfile.Exists()) {
-      cout << "Exists failed 2" << endl;
+      std::cout << "Exists failed 2" << std::endl;
       return 1;
     }
     if (diskfile.FileName() != "input1.txt") {
-      cout << "FileName failed" << endl;
+      std::cout << "FileName failed" << std::endl;
       return 1;
     }
     if (diskfile.FileSize() != strlen(input1_contents)) {
-      cout << "FileSize failed" << endl;
+      std::cout << "FileSize failed" << std::endl;
       return 1;
     }
-    const size_t buffer_len = strlen(input1_contents)+1;  // for end-of-string
+    const size_t buffer_len = strlen(input1_contents)+1;  // for end-of-std::string
     u8 *buffer = new u8[buffer_len];
-    // put end-of-string in buffer.
+    // put end-of-std::string in buffer.
     buffer[buffer_len-1] = '\0';
 
     if (!diskfile.Read(0, buffer, buffer_len - 1)) {
-      cout << "Read whole file returned false" << endl;
+      std::cout << "Read whole file returned false" << std::endl;
       return 1;
     }
-    if (string(input1_contents) != (char *) buffer) {
-      cout << "Read did not read contents correctly" << endl;
-      cout << "read     \"" << buffer << "\"" << endl;
-      cout << "expected \"" << input1_contents << "\"" << endl;
+    if (std::string(input1_contents) != (char *) buffer) {
+      std::cout << "Read did not read contents correctly" << std::endl;
+      std::cout << "read     \"" << buffer << "\"" << std::endl;
+      std::cout << "expected \"" << input1_contents << "\"" << std::endl;
       return 1;
     }
 
@@ -267,42 +270,42 @@ int test2() {
       const u64 offset = rand() % (buffer_len-1-1);
       const size_t length = 1+(rand() % (buffer_len - 1 - offset-1));
       if (!diskfile.Read(offset, buffer + offset, length)) {
-	cout << "Read partial file returned false" << endl;
-	cout << "   offset=" << offset << endl;
-	cout << "   length=" << length << endl;
-	cout << "   strlen=" << strlen(input1_contents) << endl;
+	std::cout << "Read partial file returned false" << std::endl;
+	std::cout << "   offset=" << offset << std::endl;
+	std::cout << "   length=" << length << std::endl;
+	std::cout << "   strlen=" << strlen(input1_contents) << std::endl;
 	return 1;
       }
-      if (string(input1_contents) != (char *) buffer) {
-	cout << "Random Read did not read contents correctly" << endl;
+      if (std::string(input1_contents) != (char *) buffer) {
+	std::cout << "Random Read did not read contents correctly" << std::endl;
 	return 1;
       }
     }
 
     if (!diskfile.IsOpen()) {
-      cout << "IsOpen failed 3" << endl;
+      std::cout << "IsOpen failed 3" << std::endl;
       return 1;
     }
 
     diskfile.Close();
     if (diskfile.IsOpen()) {
-      cout << "IsOpen failed 4" << endl;
+      std::cout << "IsOpen failed 4" << std::endl;
       return 1;
     }
 
     // reopen!
     if (!diskfile.Open()) {
-      cout << "Open failed 2" << endl;
+      std::cout << "Open failed 2" << std::endl;
       return 1;
     }
     if (!diskfile.IsOpen()) {
-      cout << "IsOpen failed 5" << endl;
+      std::cout << "IsOpen failed 5" << std::endl;
       return 1;
     }
 
     diskfile.Close();
     if (diskfile.IsOpen()) {
-      cout << "IsOpen failed 6" << endl;
+      std::cout << "IsOpen failed 6" << std::endl;
       return 1;
     }
 
@@ -311,109 +314,109 @@ int test2() {
 
 
   {
-    cout << "create input2.txt, move it to input3.txt, delete it." << endl;
+    std::cout << "create input2.txt, move it to input3.txt, delete it." << std::endl;
 
     const char *input2_contents = "diskfile_test test3 input2.txt is longer";
 
-    DiskFile diskfile(cout, cerr);
+    DiskFile diskfile(std::cout, std::cerr);
     if (diskfile.IsOpen()) {
-      cout << "IsOpen failed 1" << endl;
+      std::cout << "IsOpen failed 1" << std::endl;
       return 1;
     }
     if (diskfile.Exists()) {
-      cout << "Exists failed 1" << endl;
+      std::cout << "Exists failed 1" << std::endl;
       return 1;
     }
     if (!diskfile.Create("input2.txt", strlen(input2_contents))) {
-      cout << "Create failed" << endl;
+      std::cout << "Create failed" << std::endl;
       return 1;
     }
     if (!diskfile.IsOpen()) {
-      cout << "IsOpen failed 2" << endl;
+      std::cout << "IsOpen failed 2" << std::endl;
       return 1;
     }
     if (!diskfile.Exists()) {
-      cout << "Exists failed 2" << endl;
+      std::cout << "Exists failed 2" << std::endl;
       return 1;
     }
     if (diskfile.FileSize() != strlen(input2_contents)) {
-      cout << "FileSize failed 1" << endl;
+      std::cout << "FileSize failed 1" << std::endl;
       return 1;
     }
     if (diskfile.FileName() != "input2.txt") {
-      cout << "FileName failed 1" << endl;
+      std::cout << "FileName failed 1" << std::endl;
       return 1;
     }
     if (!diskfile.Write(0, input2_contents, strlen(input2_contents))) {
-      cout << "Write failed 1" << endl;
+      std::cout << "Write failed 1" << std::endl;
       return 1;
     }
 
     /*    // confirm write with read
 
-    const size_t buffer_len = strlen(input2_contents)+1;  // for end-of-string
+    const size_t buffer_len = strlen(input2_contents)+1;  // for end-of-std::string
     u8 *buffer = new u8[buffer_len];
-    // put end-of-string in buffer.
+    // put end-of-std::string in buffer.
     buffer[buffer_len-1] = '\0';
     if (!diskfile.Read(0, buffer, buffer_len - 1)) {
-      cout << "Read whole file returned false 1" << endl;
+      std::cout << "Read whole file returned false 1" << std::endl;
       return 1;
     }
-    if (string(input2_contents) != (char *) buffer) {
-      cout << "Read did not read contents correctly 1" << endl;
+    if (std::string(input2_contents) != (char *) buffer) {
+      std::cout << "Read did not read contents correctly 1" << std::endl;
       return 1;
     }
     */
 
     diskfile.Close();
     if (diskfile.IsOpen()) {
-      cout << "IsOpen failed 3" << endl;
+      std::cout << "IsOpen failed 3" << std::endl;
       return 1;
     }
 
     // Rename from input2.txt to input3.txt
     if (!diskfile.Rename("input3.txt")) {
-      cout << "Rename failed 1" << endl;
+      std::cout << "Rename failed 1" << std::endl;
       return 1;
     }
     // C's remove returns 0 on success and non-0 on failure
     if (remove("input2.txt") == 0) {
-      cout << "input2.txt exists after deletion!" << endl;
+      std::cout << "input2.txt exists after deletion!" << std::endl;
       return 1;
     }
     if (diskfile.FileName() != "input3.txt") {
-      cout << "FileName failed 1" << endl;
+      std::cout << "FileName failed 1" << std::endl;
       return 1;
     }
     if (!diskfile.Exists()) {
-      cout << "Exists failed 3" << endl;
+      std::cout << "Exists failed 3" << std::endl;
       return 1;
     }
 
     /*
     // read again
     if (!diskfile.Read(0, buffer, buffer_len - 1)) {
-      cout << "Read whole file returned false 2" << endl;
+      std::cout << "Read whole file returned false 2" << std::endl;
       return 1;
     }
-    if (string(input2_contents) != (char *) buffer) {
-      cout << "Read did not read contents correctly 2" << endl;
+    if (std::string(input2_contents) != (char *) buffer) {
+      std::cout << "Read did not read contents correctly 2" << std::endl;
       return 1;
     }
     */
 
     if (!diskfile.Delete()) {
-      cout << "Delete failed 1" << endl;
+      std::cout << "Delete failed 1" << std::endl;
       return 1;
     }
     if (diskfile.Exists()) {
-      cout << "Exists failed 4" << endl;
+      std::cout << "Exists failed 4" << std::endl;
       return 1;
     }
 
     // C's remove returns 0 on success and non-0 on failure
     if (remove("input3.txt") == 0) {
-      cout << "input3.txt exists after deletion!" << endl;
+      std::cout << "input3.txt exists after deletion!" << std::endl;
       return 1;
     }
   }
@@ -425,7 +428,7 @@ int test2() {
 
   // random write + read
   {
-    cout << "create input2.txt, write and read it." << endl;
+    std::cout << "create input2.txt, write and read it." << std::endl;
 
     const char *input2_contents = "diskfile_test test3 input2.txt is longer";
     size_t buffer_len = strlen(input2_contents);
@@ -433,10 +436,10 @@ int test2() {
     srand(23461119);
     for (size_t blocksize = 1; blocksize < buffer_len; blocksize *=2) {
       { // scope for variables used in writing
-	DiskFile diskfile(cout, cerr);
+	DiskFile diskfile(std::cout, std::cerr);
 
 	if (!diskfile.Create("input2.txt", strlen(input2_contents))) {
-	  cout << "Create failed" << endl;
+	  std::cout << "Create failed" << std::endl;
 	  return 1;
 	}
 
@@ -454,8 +457,10 @@ int test2() {
 	// write blocks
 	for (int i = 0; i < blockcount; i++) {
 	  const u64 offset = blocksize*blockorder[i];
-	  if (!diskfile.Write(offset, input2_contents + offset, blocksize)) {
-	    cout << "Write failed 1" << endl;
+	  // Calculate actual bytes to write (last block may be smaller)
+	  size_t write_len = (offset + blocksize > buffer_len) ? (buffer_len - offset) : blocksize;
+	  if (!diskfile.Write(offset, input2_contents + offset, write_len)) {
+	    std::cout << "Write failed 1" << std::endl;
 	    delete [] blockorder;
 	    return 1;
 	  }
@@ -466,23 +471,23 @@ int test2() {
       }
 
       { // scope for variables used in reading.
-	DiskFile diskfile(cout, cerr);
+	DiskFile diskfile(std::cout, std::cerr);
 
 	if (!diskfile.Open("input2.txt", strlen(input2_contents))) {
-	  cout << "Open failed 1" << endl;
+	  std::cout << "Open failed 1" << std::endl;
 	  return 1;
 	}
 
-	// add one more char, for end-of-string
+	// add one more char, for end-of-std::string
 	u8 *buffer = new u8[buffer_len + 1];
 	buffer[buffer_len] = '\0';
 
 	if (!diskfile.Read(0, buffer, buffer_len)) {
-	  cout << "Read whole file returned false 2" << endl;
+	  std::cout << "Read whole file returned false 2" << std::endl;
 	  return 1;
 	}
-	if (string(input2_contents) != (char *) buffer) {
-	  cout << "Read did not read contents correctly 2" << endl;
+	if (std::string(input2_contents) != (char *) buffer) {
+	  std::cout << "Read did not read contents correctly 2" << std::endl;
 	  return 1;
 	}
 
@@ -490,7 +495,7 @@ int test2() {
       }
 
       if (remove("input2.txt") != 0) {
-	cout << "input2.txt did not exist" << endl;
+	std::cout << "input2.txt did not exist" << std::endl;
 	return 1;
       }
     }
@@ -505,8 +510,8 @@ int test2() {
 
 // test DiskFileMap
 int test3() {
-  ofstream input1;
-  input1.open("input1.txt", ofstream::out | ofstream::binary);
+  std::ofstream input1;
+  input1.open("input1.txt", std::ofstream::out | std::ofstream::binary);
   const char *input1_contents = "diskfile_test test3 input1.txt";
   input1 << input1_contents;
   input1.close();
@@ -516,37 +521,37 @@ int test3() {
   DiskFileMap dfm;
 
   if (dfm.Find("input1.txt") != NULL) {
-    cout << "Find succeeded when it shouldn't have" << endl;
+    std::cout << "Find succeeded when it shouldn't have" << std::endl;
     return 1;
   }
 
-  DiskFile df1(cout, cerr);
+  DiskFile df1(std::cout, std::cerr);
   df1.Open("input1.txt");
   if (!dfm.Insert(&df1)) {
-    cout << "Insert failed" << endl;
+    std::cout << "Insert failed" << std::endl;
     return 1;
   }
   if (dfm.Find("input1.txt") != &df1) {
-    cout << "Find failed when it shouldn't have" << endl;
+    std::cout << "Find failed when it shouldn't have" << std::endl;
     return 1;
   }
 
-  DiskFile df2(cout, cerr);
+  DiskFile df2(std::cout, std::cerr);
   df2.Open("input1.txt");
   if (dfm.Insert(&df2)) {
-    cout << "Insert succeeded when it shouldn't have" << endl;
+    std::cout << "Insert succeeded when it shouldn't have" << std::endl;
     return 1;
   }
 
   if (dfm.Find("input1.txt") != &df1) {
-    cout << "Find failed when it shouldn't have 2" << endl;
+    std::cout << "Find failed when it shouldn't have 2" << std::endl;
     return 1;
   }
 
   dfm.Remove(&df1);
 
   if (dfm.Find("input1.txt") != NULL) {
-    cout << "Find succeeded when it shouldn't have 2" << endl;
+    std::cout << "Find succeeded when it shouldn't have 2" << std::endl;
     return 1;
   }
 
@@ -558,14 +563,14 @@ int test3() {
 
 // test FileSizeCache
 int test4() {
-  ofstream input1;
-  input1.open("input1.txt", ofstream::out | ofstream::binary);
+  std::ofstream input1;
+  input1.open("input1.txt", std::ofstream::out | std::ofstream::binary);
   const char *input1_contents = "diskfile_test test3 input1.txt";
   input1 << input1_contents;
   input1.close();
 
-  ofstream input2;
-  input2.open("input2.txt", ofstream::out | ofstream::binary);
+  std::ofstream input2;
+  input2.open("input2.txt", std::ofstream::out | std::ofstream::binary);
   const char *input2_contents = "diskfile_test test3 input2.txt is longer";
   input2 << input2_contents;
   input2.close();
@@ -575,11 +580,11 @@ int test4() {
   FileSizeCache cache;
   for (int i = 0; i < 1000; i++) {
     if (cache.get("input1.txt") != strlen(input1_contents)) {
-      cout << "FileSizeCache failed" << endl;
+      std::cout << "FileSizeCache failed" << std::endl;
       return 1;
     }
     if (cache.get("input2.txt") != strlen(input2_contents)) {
-      cout << "FileSizeCache failed 2" << endl;
+      std::cout << "FileSizeCache failed 2" << std::endl;
       return 1;
     }
   }
@@ -594,15 +599,15 @@ int test4() {
 
 // test that we cannot create a file if one already exists.
 int test5() {
-  ofstream input1;
-  input1.open("input1.txt", ofstream::out | ofstream::binary);
+  std::ofstream input1;
+  input1.open("input1.txt", std::ofstream::out | std::ofstream::binary);
   const char *input1_contents = "diskfile_test test3 input1.txt";
   input1 << input1_contents;
   input1.close();
 
-  DiskFile diskfile(cout, cerr);
+  DiskFile diskfile(std::cout, std::cerr);
   if (diskfile.Create("input1.txt", strlen(input1_contents))) {
-    cout << "Create succeeded when file already existed!" << endl;
+    std::cout << "Create succeeded when file already existed!" << std::endl;
     return 1;
   }
 
@@ -621,14 +626,14 @@ int test6() {
   const char *input1_contents = "diskfile_test test6 input1.txt";
 
   {
-    DiskFile diskfile(cout, cerr);
+    DiskFile diskfile(std::cout, std::cerr);
     if (!diskfile.Create("input1.txt", strlen(input1_contents))) {
-      cout << "Create failed!" << endl;
+      std::cout << "Create failed!" << std::endl;
       return 1;
     }
 
     if (!diskfile.Write(0, input1_contents, strlen(input1_contents), 2)) {
-      cout << "Write failed 1" << endl;
+      std::cout << "Write failed 1" << std::endl;
       return 1;
     }
 
@@ -636,27 +641,27 @@ int test6() {
   }
 
   {
-    DiskFile diskfile(cout, cerr);
+    DiskFile diskfile(std::cout, std::cerr);
 
     if (!diskfile.Open("input1.txt")) {
-      cout << "Open failed" << endl;
+      std::cout << "Open failed" << std::endl;
       return 1;
     }
 
-    const size_t buffer_len = strlen(input1_contents)+1;  // for end-of-string
+    const size_t buffer_len = strlen(input1_contents)+1;  // for end-of-std::string
     u8 *buffer = new u8[buffer_len];
-    // put end-of-string in buffer.
+    // put end-of-std::string in buffer.
     buffer[buffer_len-1] = '\0';
 
     if (!diskfile.Read(0, buffer, buffer_len - 1, 2)) {
-      cout << "Read whole file returned false" << endl;
+      std::cout << "Read whole file returned false" << std::endl;
       return 1;
     }
 
-    if (string(input1_contents) != (char *) buffer) {
-      cout << "Read did not read contents correctly" << endl;
-      cout << "read     \"" << buffer << "\"" << endl;
-      cout << "expected \"" << input1_contents << "\"" << endl;
+    if (std::string(input1_contents) != (char *) buffer) {
+      std::cout << "Read did not read contents correctly" << std::endl;
+      std::cout << "read     \"" << buffer << "\"" << std::endl;
+      std::cout << "expected \"" << input1_contents << "\"" << std::endl;
       return 1;
     }
 
@@ -670,19 +675,19 @@ int test6() {
 
   // try again, writing mid-file with different maxlength.
   {
-    DiskFile diskfile(cout, cerr);
+    DiskFile diskfile(std::cout, std::cerr);
     if (!diskfile.Create("input2.txt", strlen(input2_contents))) {
-      cout << "Create 2 failed." << endl;
+      std::cout << "Create 2 failed." << std::endl;
       return 1;
     }
 
     size_t midpoint = strlen(input2_contents);
     if (!diskfile.Write(midpoint, input2_contents + midpoint, strlen(input2_contents) - midpoint, 3)) {
-      cout << "Write failed 2" << endl;
+      std::cout << "Write failed 2" << std::endl;
       return 1;
     }
     if (!diskfile.Write(0, input2_contents, midpoint, 4)) {
-      cout << "Write failed 3" << endl;
+      std::cout << "Write failed 3" << std::endl;
       return 1;
     }
 
@@ -691,33 +696,33 @@ int test6() {
 
 
   {
-    DiskFile diskfile(cout, cerr);
+    DiskFile diskfile(std::cout, std::cerr);
 
     if (!diskfile.Open("input2.txt")) {
-      cout << "Open failed" << endl;
+      std::cout << "Open failed" << std::endl;
       return 1;
     }
 
-    const size_t buffer_len = strlen(input2_contents)+1;  // for end-of-string
+    const size_t buffer_len = strlen(input2_contents)+1;  // for end-of-std::string
     u8 *buffer = new u8[buffer_len];
-    // put end-of-string in buffer.
+    // put end-of-std::string in buffer.
     buffer[buffer_len-1] = '\0';
 
 
     size_t midpoint = strlen(input2_contents) - 2;
     if (!diskfile.Read(midpoint, buffer + midpoint, strlen(input2_contents) - midpoint, 4)) {
-      cout << "Read second half of file returned false" << endl;
+      std::cout << "Read second half of file returned false" << std::endl;
       return 1;
     }
     if (!diskfile.Read(0, buffer, midpoint, 3)) {
-      cout << "Read first half of file returned false" << endl;
+      std::cout << "Read first half of file returned false" << std::endl;
       return 1;
     }
 
-    if (string(input2_contents) != (char *) buffer) {
-      cout << "Read did not read contents correctly" << endl;
-      cout << "read     \"" << buffer << "\"" << endl;
-      cout << "expected \"" << input2_contents << "\"" << endl;
+    if (std::string(input2_contents) != (char *) buffer) {
+      std::cout << "Read did not read contents correctly" << std::endl;
+      std::cout << "read     \"" << buffer << "\"" << std::endl;
+      std::cout << "expected \"" << input2_contents << "\"" << std::endl;
       return 1;
     }
 
@@ -732,31 +737,31 @@ int test6() {
 
 int main() {
   if (test1()) {
-    cerr << "FAILED: test1" << endl;
+    std::cerr << "FAILED: test1" << std::endl;
     return 1;
   }
   if (test2()) {
-    cerr << "FAILED: test2" << endl;
+    std::cerr << "FAILED: test2" << std::endl;
     return 1;
   }
   if (test3()) {
-    cerr << "FAILED: test3" << endl;
+    std::cerr << "FAILED: test3" << std::endl;
     return 1;
   }
   if (test4()) {
-    cerr << "FAILED: test4" << endl;
+    std::cerr << "FAILED: test4" << std::endl;
     return 1;
   }
   if (test5()) {
-    cerr << "FAILED: test5" << endl;
+    std::cerr << "FAILED: test5" << std::endl;
     return 1;
   }
   if (test6()) {
-    cerr << "FAILED: test6" << endl;
+    std::cerr << "FAILED: test6" << std::endl;
     return 1;
   }
 
-  cout << "SUCCESS: diskfile_test complete." << endl;
+  std::cout << "SUCCESS: diskfile_test complete." << std::endl;
 
   return 0;
 }
