@@ -20,7 +20,6 @@
 
 #include "libpar2.h"
 #include "commandline.h"
-
 // This is included here, so that cout and cerr are not used elsewhere.
 #include <iostream>
 
@@ -32,11 +31,26 @@ static char THIS_FILE[]=__FILE__;
 #endif
 #endif
 
-int main(int argc, char *argv[])
+#ifdef _WIN32
+
+#include "utf8.h"
+
+int wmain(int argc, wchar_t* wargv[])
+
+#else
+
+int main(int argc, char* argv[])
+
+#endif
 {
 #ifdef _MSC_VER
   // Memory leak checking
   _CrtSetDbgFlag(_CrtSetDbgFlag(_CRTDBG_REPORT_FLAG) | _CRTDBG_ALLOC_MEM_DF | /*_CRTDBG_CHECK_CRT_DF | */_CRTDBG_DELAY_FREE_MEM_DF | _CRTDBG_LEAK_CHECK_DF);
+
+  SetConsoleOutputCP(CP_UTF8);
+
+  utf8::WideToUtf8ArgsAdapter wargsAdapter{ argc, wargv };
+  auto argv = wargsAdapter.GetUtf8Args();
 #endif
 
   // check sizeof integers
@@ -46,7 +60,7 @@ int main(int argc, char *argv[])
 		|| sizeof(u64) == 8 || sizeof(i64) == 1,
 		"Error: the assumed sizes of integers is wrong!");
 
-  
+
   // Parse the command line
   CommandLine *commandline = new CommandLine;
 
@@ -72,7 +86,7 @@ int main(int argc, char *argv[])
 			    commandline->GetExtraFiles(),
 
 			    commandline->GetBlockSize(),
-			    
+
 			    commandline->GetFirstRecoveryBlock(),
 			    commandline->GetRecoveryFileScheme(),
 			    commandline->GetRecoveryFileCount(),
@@ -98,7 +112,7 @@ int main(int argc, char *argv[])
 				  commandline->GetExtraFiles(),
 				  commandline->GetOperation() == CommandLine::opRepair,
 				  commandline->GetPurgeFiles());
-	      
+
               break;
             case CommandLine::verPar2:
 	      result = par2repair(std::cout,
@@ -114,6 +128,7 @@ int main(int argc, char *argv[])
 				  commandline->GetExtraFiles(),
 				  commandline->GetOperation() == CommandLine::opRepair,
 				  commandline->GetPurgeFiles(),
+				  commandline->GetRenameOnly(),
 				  commandline->GetSkipData(),
 				  commandline->GetSkipLeaway());
               break;
